@@ -4,15 +4,16 @@ import boto3
 from urllib.parse import urlparse
 from time import sleep
 from .relycomply_gql_client import RelyComplyGQLClient
+from .exceptions import RelyComplyClientException
 
 s3_client = boto3.client("s3")
 
 
 class RelyComplyClient:
-    def __init__(self):
+    def __init__(self, **kwargs):
 
         # Expose the raw-ish gql client
-        self.gql = RelyComplyGQLClient()
+        self.gql = RelyComplyGQLClient(**kwargs)
 
     def object_id(self, obj_or_id):
         """
@@ -59,7 +60,12 @@ class RelyComplyClient:
                 allow_truncated_timestamps=True,
                 use_deprecated_int96_timestamps=True,
             )
-            requests.put(datafile["putUrl"], data=fp).raise_for_status()
+            try:
+                requests.put(datafile["putUrl"], data=fp).raise_for_status()
+            except Exception as e:
+                raise RelyComplyClientException(
+                    f"Error uploading to DataFile {datafile['id']}:{str(e)}"
+                )
 
         return datafile
 
@@ -74,7 +80,7 @@ class RelyComplyClient:
                 if datafile["status"] != "LOADING":
                     break
         if datafile["status"] == "ERROR":
-            raise Exception(
+            raise RelyComplyClientException(
                 f"Error pulling datafile {datafile['id']}: {datafile['error']}"
             )
         return datafile
@@ -98,7 +104,7 @@ class RelyComplyClient:
             status = version["status"]
 
         if status == "ERROR":
-            raise Exception(
+            raise RelyComplyClientException(
                 f"Error ingesting DataSourceVersion {version['id']}: {version['error']}"
             )
 
